@@ -14,4 +14,4 @@ class AISConfig(Config, Singleton):
     Singleton.__init__(self)
 
 __config_singleton = AISConfig('/apps/advanced-interface-switcher')
-def get_config(): return __config_singleton
+def get(): return __config_singleton
